pub struct AggregatedMetricsProcessor;Expand description
Aggregated metrics processor.
This processor maintains a map of aggregated metrics, where each metric is represented by its context (name and tags), and the aggregated value of the metric. Counters, gauges, and histograms are supported; all other metric types are ignored.
Aggregation follows the following rules:
- Counters are summed together.
- Gauges are represented by the latest value (by timestamp).
- Histograms are merged: per-bucket counts, sum, and total count are summed.
Aggregated values have no concept of “points” – specific values at a specific timestamp – or multiple data points: each metric simply has a single value that represents the aggregated amount since the processor was created.