pub struct MetricsSnapshot {
pub upserts: Vec<Event>,
pub evictions: Vec<Context>,
}Expand description
A batch of metric updates produced by a single flush.
Fields
upserts: Vec<Event>Updates to active metrics.
evictions: Vec<Context>Metrics which are no longer active and should be removed.