pub struct Reflector<P: Processor> { /* private fields */ }Expand description
Reflector composes a source of data with a processor that’s used to transform the data, and then stores the
results and allows for shared access by multiple callers.
Reflectors are a term often found in the context of custom Kubernetes controllers, where they’re used to reduce the
load on the Kubernetes API server by caching the state of resources in memory. Reflector provides comparable
functionality, allowing for a single data source to be consumed, and then shared amongst multiple callers. However,
Reflector utilizes the concept of a processor, which dictates both the type of data that can be consumed and
data that gets stored. This means that Reflector is more than just a cache of the data source, but also
potentially a mapped version of it, allowing for transforming the data in whatever way is necessary.
Implementations
Sourceimpl<P: Processor> Reflector<P>
impl<P: Processor> Reflector<P>
Sourcepub fn new<S, I>(source: S, processor: P) -> (Self, ReflectorWorker<P, S>)
pub fn new<S, I>(source: S, processor: P) -> (Self, ReflectorWorker<P, S>)
Creates a new reflector with the given data source and processor.
A reflector composes a source of data with a processor that’s used to transform the data, and then stores the processed results. It can be listened to for updates, and cheaply shared. This allows multiple interested components to subscribe to the same data source without having to duplicate the processing or storage of the data.
Returns the reflector alongside a ReflectorWorker that consumes the data source and feeds the processed
items into the shared state. The reflector is usable immediately, but reports only the initial state until
the worker is added to a Supervisor and starts running. Register the worker
as transient, for the reasons given on ReflectorWorker.
Reflector is cheaply cloneable and can either be cloned for each caller or shared between them (for example, via
Arc<T>).