RemapperRule

Struct RemapperRule 

pub struct RemapperRule { /* private fields */ }
A metric remapping rule.

Rules define the basic matching behavior (metric name, and optionally tags) as well as how to remap the new copy of the metric. This can include copying tags as-is from the source metric, copying specific tags over with a new name, and adding an additional fixed set of tags to the new metric.

Implementations

Source

impl RemapperRule

pub fn by_name(existing_name: &'static str, new_name: &'static str) -> Self

Creates a new RemapperRule that matches a source metric by name only.

pub fn by_name_and_tags( existing_name: &'static str, existing_tags: &'static [&'static str], new_name: &'static str, ) -> Self

Creates a new RemapperRule that matches a source metric by name and tags.

pub fn with_remapped_tags<I>(self, remapped_tags: I) -> Self
where I: IntoIterator<Item = (&'static str, &'static str)>,

Adds a set of tags to remap from the source metric by changing their name.

Remapped tags must be given in the form of (source_tag, destination_tag). If a tag by the name source_tag is found in the source metric, it’s copied to the remapped metric with a name of destination_tag.

This method is additive, so it can be called multiple times to add more remapped tags. Tag remapping is order-dependent, so if a tag is configured to be remapped, or copied, multiple times, then the first match will take precedence.

pub fn with_original_tags<I>(self, original_tags: I) -> Self
where I: IntoIterator<Item = &'static str>,

Adds a set of tags to remap from the source metric without changing their name.

Remapped tags must be given in the form of source_tag. If a tag by the name source_tag is found in the source metric, it’s copied to the remapped metric with the same name.

This method is additive, so it can be called multiple times to add more original tags. Tag remapping is order-dependent, so if a tag is configured to be copied, or remapped, multiple times, then the first match will take precedence.

pub fn with_additional_tags<I>(self, additional_tags: I) -> Self
where I: IntoIterator<Item = &'static str>,

Adds a fixed set of tags to add to the remapped metric.

Additional tags are given in the form of tag, which can be any valid tag value: bare or key/value.

This method is additive, so it can be called multiple times to add more additional tags.

pub fn with_continued_matching(self) -> Self

Allows later rules to also match the same source metric.

pub fn with_help_text(self, help_text: &'static str) -> Self

Sets the Prometheus # HELP text that should be emitted alongside the remapped metric.

Some downstream collectors (notably the Datadog Agent’s OpenMetrics check) require a specific help text on overlapped metric names. Setting this here keeps the help text next to the rule that produces the name.

pub const fn should_continue_matching(&self) -> bool

Returns true if matching should continue after this rule matches.

pub const fn remapped_name(&self) -> &'static str

Returns the remapped metric name produced by this rule.

pub const fn help_text(&self) -> Option<&'static str>

Returns the help text associated with this rule, if any.

pub fn try_match_no_context(&self, context: &Context) -> Option<RemappedMetric>

Attempts to match the given context against this rule.

If the rule matches, returns a RemappedMetric containing the new metric name and tags.